import { BackendDeployer, DeployProps } from './cdk_deployer_singleton_factory.js';
import { CdkErrorMapper } from './cdk_error_mapper.js';
import { UniqueBackendIdentifier } from '@aws-amplify/plugin-types';
/**
 * Invokes CDK command via execa
 */
export declare class CDKDeployer implements BackendDeployer {
    private readonly cdkErrorMapper;
    /**
     * Instantiates instance of CDKDeployer
     */
    constructor(cdkErrorMapper: CdkErrorMapper);
    /**
     * Invokes cdk deploy command
     */
    deploy: (uniqueBackendIdentifier?: UniqueBackendIdentifier, deployProps?: DeployProps) => Promise<void>;
    /**
     * Invokes cdk destroy command
     */
    destroy: (uniqueBackendIdentifier?: UniqueBackendIdentifier) => Promise<void>;
    /**
     * Executes a CDK command
     */
    private invoke;
    /**
     * Wrapper for the child process executor. Helps in unit testing as node:test framework
     * doesn't have capabilities to mock exported functions like `execa` as of right now.
     */
    executeChildProcess: (command: string, cdkCommandArgs: string[]) => Promise<void>;
}
//# sourceMappingURL=cdk_deployer.d.ts.map